/**********************************************************************
DESCRIPTION :
This module merges the commands from the TTC and VME:
- Hard_rst, Soft_rst, Start and Stop are simply OR'ed;
- Any hard reset generates also Soft_Rst.
- Start and Stop determine the state variable run_status;
- GateTTCcommands inhibits TTC_Start and TTC_Stop; this will allow 
  the use of TTC with partial readout chains (Jeremiah Mans).
************************************************************************/

`timescale 1ns / 1ns
module commander ( 
  input  clk,   GateTTCcommands,	
         TTC_Hard_rst, TTC_Soft_rst,
         TTC_Start, TTC_Stop,
         VME_Hard_rst, VME_Soft_rst, 
         VME_Start, VME_Stop, 
  output reg Hard_rst, Soft_rst, run_status  );

 reg   Start = 0; 
 reg   Stop  = 1;

 always @ (posedge clk)  // no reset condition as this module generates the reset
   begin   // clk			 
    Hard_rst <= TTC_Hard_rst | VME_Hard_rst; //  Hard_Rst implies Soft_rst...
    Soft_rst <= TTC_Soft_rst | VME_Soft_rst | TTC_Hard_rst | VME_Hard_rst;
    Start <= VME_Start | (~GateTTCcommands & TTC_Start);
    Stop  <= VME_Stop  | (~GateTTCcommands & TTC_Stop);
    if (Start)   run_status <= 1; // Start prevails on a simultaneous Stop.
    else if (Stop)  run_status <= 0;
  end   // clk	     

endmodule  